@@ -4,9 +4,9 @@ import (
 	"testing"
 
 	"github.com/alecthomas/assert/v2"
-	vfs "github.com/twpayne/go-vfs/v4"
+	vfs "github.com/twpayne/go-vfs/v5"
 
-	"github.com/twpayne/chezmoi/v2/internal/chezmoitest"
+	"github.com/twpayne/chezmoi/internal/chezmoitest"
 )
 
 func TestPatternSet(t *testing.T) {
