@@ -60,9 +60,9 @@ func (s *RealSystem) WriteFile(filename AbsPath, data []byte, perm fs.FileMode)
 }
 
 // WriteSymlink implements System.WriteSymlink.
-func (s *RealSystem) WriteSymlink(oldname string, newname AbsPath) error {
-	if err := s.fileSystem.RemoveAll(newname.String()); err != nil && !errors.Is(err, fs.ErrNotExist) {
+func (s *RealSystem) WriteSymlink(oldName string, newName AbsPath) error {
+	if err := s.fileSystem.RemoveAll(newName.String()); err != nil && !errors.Is(err, fs.ErrNotExist) {
 		return err
 	}
-	return s.fileSystem.Symlink(filepath.FromSlash(oldname), newname.String())
+	return s.fileSystem.Symlink(filepath.FromSlash(oldName), newName.String())
 }
