@@ -11,7 +11,7 @@ import (
 	"github.com/coreos/go-semver/semver"
 	vfs "github.com/twpayne/go-vfs/v5"
 
-	"github.com/twpayne/chezmoi/v2/internal/chezmoitest"
+	"github.com/twpayne/chezmoi/internal/chezmoitest"
 )
 
 var _ System = &TarWriterSystem{}
