@@ -40,7 +40,7 @@ func TestPasswordInputModel(t *testing.T) {
 		},
 	} {
 		t.Run(tc.name, func(t *testing.T) {
-			actualModel := testRunModelWithInput(t, NewPasswordInputModel("prompt"), tc.input)
+			actualModel := testRunModelWithInput(t, NewPasswordInputModel("prompt", "placeholder"), tc.input)
 			assert.Equal(t, tc.expectedCanceled, actualModel.Canceled())
 			assert.Equal(t, tc.expectedValue, actualModel.Value())
 		})
