@@ -5,7 +5,7 @@ import (
 
 	"golang.org/x/term"
 
-	"github.com/twpayne/chezmoi/v2/internal/chezmoi"
+	"github.com/twpayne/chezmoi/internal/chezmoi"
 )
 
 func (c *Config) exitInitTemplateFunc(code int) string {
@@ -25,9 +25,7 @@ func (c *Config) stdinIsATTYInitTemplateFunc() bool {
 
 func (c *Config) writeToStdout(args ...string) string {
 	for _, arg := range args {
-		if _, err := c.stdout.Write([]byte(arg)); err != nil {
-			panic(err)
-		}
+		_ = mustValue(c.stdout.Write([]byte(arg)))
 	}
 	return ""
 }
