@@ -3,7 +3,7 @@ package cmd
 import (
 	"github.com/spf13/cobra"
 
-	"github.com/twpayne/chezmoi/v2/internal/chezmoi"
+	"github.com/twpayne/chezmoi/internal/chezmoi"
 )
 
 func (c *Config) newRemoveCmd() *cobra.Command {
@@ -15,6 +15,7 @@ func (c *Config) newRemoveCmd() *cobra.Command {
 		Long:       mustLongHelp("remove"),
 		Annotations: newAnnotations(
 			doesNotRequireValidConfig,
+			persistentStateModeNone,
 		),
 	}
 
