@@ -1,6 +1,7 @@
 package cmd
 
 import (
+	"context"
 	"encoding/hex"
 	"encoding/json"
 	"errors"
@@ -8,6 +9,7 @@ import (
 	"io"
 	"io/fs"
 	"maps"
+	"net/http"
 	"os"
 	"os/exec"
 	"path/filepath"
@@ -65,28 +67,10 @@ var errEmptyPath = errors.New("empty path")
 var needsQuoteRx = regexp.MustCompile(`[^\x21\x23-\x5b\x5d-\x7e]`)
 
 func (c *Config) commentTemplateFunc(prefix, s string) string {
-	type stateType int
-	const (
-		startOfLine stateType = iota
-		inLine
-	)
-
-	state := startOfLine
 	var builder strings.Builder
-	for _, r := range s {
-		switch state {
-		case startOfLine:
-			_ = mustValue(builder.WriteString(prefix))
-			_ = mustValue(builder.WriteRune(r))
-			if r != '\n' {
-				state = inLine
-			}
-		case inLine:
-			_ = mustValue(builder.WriteRune(r))
-			if r == '\n' {
-				state = startOfLine
-			}
-		}
+	for line := range strings.Lines(s) {
+		builder.WriteString(prefix)
+		builder.WriteString(line)
 	}
 	return builder.String()
 }
@@ -122,6 +106,26 @@ func (c *Config) eqFoldTemplateFunc(first, second string, more ...string) bool {
 	return false
 }
 
+func (c *Config) ensureLinePrefixTemplateFunc(args ...string) string {
+	var prefix, prefixToAdd, s string
+	switch len(args) {
+	case 2:
+		prefix, prefixToAdd, s = args[0], args[0], args[1]
+	case 3:
+		prefix, prefixToAdd, s = args[0], args[1], args[2]
+	default:
+		panic(fmt.Errorf("expected 2 or 3 arguments, got %d", len(args)))
+	}
+	var builder strings.Builder
+	for line := range strings.Lines(s) {
+		if !strings.HasPrefix(line, prefix) {
+			builder.WriteString(prefixToAdd)
+		}
+		builder.WriteString(line)
+	}
+	return builder.String()
+}
+
 func (c *Config) findExecutableTemplateFunc(file string, pathList any) string {
 	files := []string{file}
 	paths, err := anyToStringSlice(pathList)
@@ -188,6 +192,14 @@ func (c *Config) fromYamlTemplateFunc(s string) any {
 	return value
 }
 
+func (c *Config) getRedirectedURLTemplateFunc(requestURL string) string {
+	client := mustValue(c.getHTTPClient())
+	req := mustValue(http.NewRequestWithContext(context.Background(), http.MethodHead, requestURL, http.NoBody))
+	resp := mustValue(client.Do(req)) //nolint:bodyclose
+	defer resp.Body.Close()
+	return resp.Request.URL.String()
+}
+
 func (c *Config) globTemplateFunc(pattern string) []string {
 	defer func() {
 		value := recover()
