@@ -3,17 +3,18 @@ package cmd
 import (
 	"fmt"
 	"io/fs"
-	"sort"
+	"slices"
 
 	"github.com/spf13/cobra"
 
-	"github.com/twpayne/chezmoi/v2/internal/chezmoi"
-	"github.com/twpayne/chezmoi/v2/internal/chezmoiset"
+	"github.com/twpayne/chezmoi/internal/chezmoi"
+	"github.com/twpayne/chezmoi/internal/chezmoiset"
 )
 
 type unmanagedCmdConfig struct {
-	pathStyle *choiceFlag
-	tree      bool
+	nulPathSeparator bool
+	pathStyle        *choiceFlag
+	tree             bool
 }
 
 func (c *Config) newUnmanagedCmd() *cobra.Command {
@@ -29,6 +30,8 @@ func (c *Config) newUnmanagedCmd() *cobra.Command {
 		),
 	}
 
+	unmanagedCmd.Flags().
+		BoolVarP(&c.unmanaged.nulPathSeparator, "nul-path-separator", "0", c.unmanaged.nulPathSeparator, "Use the NUL character as a path separator")
 	unmanagedCmd.Flags().VarP(c.unmanaged.pathStyle, "path-style", "p", "Path style")
 	must(unmanagedCmd.RegisterFlagCompletionFunc("path-style", c.unmanaged.pathStyle.FlagCompletionFunc()))
 	unmanagedCmd.Flags().BoolVarP(&c.unmanaged.tree, "tree", "t", c.unmanaged.tree, "Print paths as a tree")
@@ -37,7 +40,7 @@ func (c *Config) newUnmanagedCmd() *cobra.Command {
 }
 
 func (c *Config) runUnmanagedCmd(cmd *cobra.Command, args []string, sourceState *chezmoi.SourceState) error {
-	var absPaths chezmoi.AbsPaths
+	var absPaths []chezmoi.AbsPath
 	if len(args) == 0 {
 		absPaths = append(absPaths, c.DestDirAbsPath)
 	} else {
@@ -49,8 +52,8 @@ func (c *Config) runUnmanagedCmd(cmd *cobra.Command, args []string, sourceState
 			}
 			argsAbsPaths.Add(argAbsPath)
 		}
-		absPaths = chezmoi.AbsPaths(argsAbsPaths.Elements())
-		sort.Sort(absPaths)
+		absPaths = argsAbsPaths.Elements()
+		slices.Sort(absPaths)
 	}
 
 	unmanagedRelPaths := chezmoiset.New[chezmoi.RelPath]()
@@ -112,6 +115,7 @@ func (c *Config) runUnmanagedCmd(cmd *cobra.Command, args []string, sourceState
 	}
 
 	return c.writePaths(stringersToStrings(paths), writePathsOptions{
-		tree: c.unmanaged.tree,
+		nulPathSeparator: c.unmanaged.nulPathSeparator,
+		tree:             c.unmanaged.tree,
 	})
 }
